/*global define, window, rss*/

define([
    'testsuite/qunit',
    'jquery',
    './rss-view',

    '$ready!'
], function (QUnit, $, RssView) {
    'use strict';

    QUnit.module('de_epages/externalcontent/gadgetdialog/rss-view', {
        setup: function () {
            window.rss = new RssView();
            $('#qunit-fixture').append(rss.render().el);
        },
        teardown: function () {
            $('#qunit-fixture').empty();
        }
    });

    QUnit.test('Test view methods', 3, function () {
        $.each(['getAPI', 'getFeed', 'onUrlKeypress'], function (i, method) {
            QUnit.strictEqual(
                $.isFunction(rss[method]),
                true,
                method + ' is a method of rss view'
            );
        });
    });

    QUnit.asyncTest('Test rss view', 13, function () {
        var url = 'http://www.spiegel.de/schlagzeilen/tops/index.rss';

        QUnit.strictEqual(
            $('#ep-gadgets-rss').length,
            1,
            'Create rss view'
        );

        QUnit.strictEqual(
            $('.PreviewNode').children().length,
            0,
            'Preview is empty'
        );

        $('input[name="url"]').val(url);
        rss.getFeed(url);

        // we have to wait until rss feed is fully loaded
        window.setTimeout(function () {
            var entries = $('#numberOfEntries').val();

            QUnit.strictEqual(
                $('.PreviewNode').children().length,
                1,
                'Preview of rss feed is loaded'
            );

            QUnit.deepEqual(
                rss.gOptions,
                {"url": "http://www.spiegel.de/schlagzeilen/tops/index.rss", "numberOfEntries": 10, "onlyHeadlines": false, "onlySnippets": false, "showImages": true, "layout": "default"},
                "Get default options"
            );

            QUnit.strictEqual(
                $('.rss-content:first').text().length > 200,
                true,
                'Display long text by default'
            );

            QUnit.strictEqual(
                $('.rss-content').length > 0,
                true,
                'Display content by default'
            );

            QUnit.strictEqual(
                $('.rss-feed .rss-title').length.toString(),
                entries,
                'Display ' + entries + ' entries'
            );

            QUnit.strictEqual(
                $('.rss-feed').find('img').length > 0,
                true,
                'Display images'
            );

            $('#showImages').trigger('click');

            QUnit.strictEqual(
                $('.rss-feed').find('img').length > 0,
                false,
                'Do not display images'
            );

            $('#layout').val('box').trigger('change');
            $('#onlySnippets').trigger('click');
            $('#onlyHeadlines').trigger('click');

            window.setTimeout(function () {
                QUnit.deepEqual(
                    rss.gOptions,
                    {"url": "http://www.spiegel.de/schlagzeilen/tops/index.rss", "numberOfEntries": 10, "onlyHeadlines": true, "onlySnippets": true, "showImages": false, "layout": "box"},
                    "Get options after change"
                );

                QUnit.strictEqual(
                    $('.rss-content:first').text().length < 200,
                    true,
                    'Display shortened text'
                );

                QUnit.strictEqual(
                    $('.rss-content').length > 0,
                    false,
                    'Display only headlines'
                );

                QUnit.strictEqual(
                    $('.PreviewNode').children().hasClass('Box'),
                    true,
                    'Use layout *box*'
                );

                QUnit.start();

            }, 500);
        }, 500);

    });

});